@@ -83,7 +83,7 @@ namespace Utils{
 
 		// outputs
 		bool output_gamma, output_beta, output_sigmaRho,
-			output_G, output_pi, output_tail, output_model_size, output_CPO, output_model_visit;
+			output_Gy, output_pi, output_tail, output_model_size, output_CPO, output_model_visit;
         
 	};
 
